@@ -1,13 +1,14 @@
 use strict;
 
 package HTML::FormFu::Exception::Input;
-$HTML::FormFu::Exception::Input::VERSION = '2.06';
+# ABSTRACT: Input exception
+$HTML::FormFu::Exception::Input::VERSION = '2.07';
 use Moose;
 use MooseX::Attribute::Chained;
 extends 'HTML::FormFu::Exception';
 
 use HTML::FormFu::Attribute qw( mk_attrs );
-use HTML::FormFu::Util qw( append_xml_attribute literal xml_escape );
+use HTML::FormFu::Util qw( append_xml_attribute literal xml_escape _merge_hashes );
 
 has processor => ( is => 'rw', traits => ['Chained'] );
 has forced    => ( is => 'rw', traits => ['Chained'] );
@@ -93,7 +94,10 @@ around render_data_non_recursive => sub {
 sub _render_attributes {
     my ( $self, $render ) = @_;
 
-    my $attrs = xml_escape( $self->attributes );
+    my $attrs = xml_escape(
+        $self->parent->error_attributes,
+        $self->attributes,
+    );
 
     my $auto_error_class = $self->parent->auto_error_class;
 
@@ -128,11 +132,11 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::Exception::Input
+HTML::FormFu::Exception::Input - Input exception
 
 =head1 VERSION
 
-version 2.06
+version 2.07
 
 =head1 AUTHOR
 
