@@ -1,7 +1,8 @@
 use strict;
 
 package HTML::FormFu::I18N::fr;
-$HTML::FormFu::I18N::fr::VERSION = '2.06';
+# ABSTRACT: French
+$HTML::FormFu::I18N::fr::VERSION = '2.07';
 use utf8;
 
 use Moose;
@@ -60,11 +61,11 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::I18N::fr
+HTML::FormFu::I18N::fr - French
 
 =head1 VERSION
 
-version 2.06
+version 2.07
 
 =head1 AUTHOR
 
