@@ -1,7 +1,8 @@
 use strict;
 
 package HTML::FormFu::I18N::ja;
-$HTML::FormFu::I18N::ja::VERSION = '2.06';
+# ABSTRACT: Japanese
+$HTML::FormFu::I18N::ja::VERSION = '2.07';
 use utf8;
 
 use Moose;
@@ -69,11 +70,11 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::I18N::ja
+HTML::FormFu::I18N::ja - Japanese
 
 =head1 VERSION
 
-version 2.06
+version 2.07
 
 =head1 AUTHOR
 
